@@ -1,4 +1,4 @@
-from logilab.mtconverter import html_escape
+from logilab.mtconverter import xml_escape
 
 from cubicweb.view import EntityView
 from cubicweb.selectors import implements
@@ -11,8 +11,8 @@ class RecurrentDayOutOfContext(baseviews.OutOfContextView):
     __select__ = implements('Recurrentday')
 
     def cell_call(self, row, col):
-        entity = self.entity(row,col)
-        self.w(u'<a href="%s">' % html_escape(entity.absolute_url(vid='edition')))
+        entity = self.cw_rset.get_entity(row,col)
+        self.w(u'<a href="%s">' % xml_escape(entity.absolute_url(vid='edition')))
         self.wdata(entity.dc_long_title())
         self.w(u'</a>')
 
@@ -20,8 +20,8 @@ class TimePeriodOutOfContext(baseviews.OutOfContextView):
     __select__ = implements('Timeperiod')
 
     def cell_call(self, row, col):
-        entity = self.entity(row,col)
-        self.w(u'<a href="%s">' % html_escape(entity.absolute_url(vid='edition')))
+        entity = self.cw_rset.get_entity(row,col)
+        self.w(u'<a href="%s">' % xml_escape(entity.absolute_url(vid='edition')))
         self.wdata(entity.dc_long_title())
         self.w(u'</a>')
 
